@@ -1,5 +1,4 @@
-#ifndef CONSTRAINTS_TO_R_CLASS_H
-#define CONSTRAINTS_TO_R_CLASS_H
+#pragma once
 
 #include "Constraints/ConstraintsClass.h"
 #include "ClassUtils/ComboResClass.h"
@@ -36,7 +35,7 @@ public:
         std::vector<int> &RstartZ, const std::string &RmainFun,
         const std::string &RFunTest, funcPtr<double> RfunDbl,
         ConstraintType Rctype, int RstrtLen, int Rcap, bool RKeepRes,
-        bool RnumUnknown, double RcnstrtRows, mpz_t RcnstrtRowsMpz
+        bool RnumUnknown, double RcnstrtRows, const mpz_class &RcnstrtRowsMpz
     );
 
     void startOver();
@@ -46,5 +45,3 @@ public:
     SEXP currComb();
     SEXP summary();
 };
-
-#endif
