@@ -1,7 +1,7 @@
 #pragma once
 
 #include <vector>
-#include "CppConvert/GmpxxCopy.h"
+#include <gmpxx.h>
 
 void NumPermsWithRepGmp(mpz_class &result, const std::vector<int> &v);
 void NumPermsNoRepGmp(mpz_class &result, int n, int m);
